@@ -28,7 +28,7 @@ class AsyncMessageBus(AbstractMessagebus):
         return self._loop
 
     async def start(self):
-        self._start_event = asyncio.Event(loop=self.loop)
+        self._start_event = asyncio.Event()
         self._daemon_task = self.loop.create_task(self._run_daemon())
         await self._start_event.wait()
 
